<?php
/**
 * Copyright 2014 Klarna AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File containing the Capture class.
 */

namespace Klarna\Rest\Settlements;

use GuzzleHttp\Exception\RequestException;
use Klarna\Rest\Resource;
use Klarna\Rest\Transport\Connector;
use Klarna\Rest\Transport\Exception\ConnectorException;

/**
 * Payouts resource.
 *
 */
class Payouts extends Resource
{
    /**
     * {@inheritDoc}
     */
    const ID_FIELD = 'payment_reference';

    /**
     * {@inheritDoc}
     */
    public static $path = '/settlements/v1/payouts';

    /**
     * Constructs an payout instance.
     *
     * @param Connector $connector HTTP transport connector
     * @param string    $payment_reference payment reference
     */
    public function __construct(Connector $connector)
    {
        parent::__construct($connector);

        $this->setLocation(self::$path);

    }

    /**
     * Fetches the payout
     *
     * @param string    $payment_reference  The reference id of the payout
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function getPayout($payment_reference)
    {
        $this->setLocation(self::$path."/{$payment_reference}");

        parent::fetch();

        return $this;
    }

    /**
     * Fetches a page of payouts.
     *
     * @param int   $offset page offset, default 0
     * @param int   $size   page size, default 20
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function page($offset = 0, $size = 20, $start_date = null, $end_date = null, $currency_code = null)
    {
        $params = http_build_query( array(
            'offset' => $offset,
            'size' => $size,
            'start_date' => $start_date,
            'end_date' => $end_date,
            'currency_code' => $currency_code
        ));
        $this->setLocation(self::$path."?{$params}" );
        parent::fetch();

        return $this;
    }

    /**
     * Returns a summary of payouts for each currency code in a date range
     *
     * @param string    $start_date     ISO-8601/DateTime::ATOM formatted date with optional time string  DateTime::ATOM
     * @param string    $end_date       ISO-8601/DateTime::ATOM formatted date with optional time string
     * @param string    $currency_code  ISO-3166 Currency Code
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function getSummary($start_date, $end_date , $currency_code)
    {
        $params = http_build_query( array(
            'start_date' => $start_date,
            'end_date' => $end_date,
            'currency_code' => $currency_code
        ));

        $this->setLocation(self::$path."/summary?{$params}" );
        parent::fetch();

        return $this;
    }


}
