<?php
/**
 * Copyright 2014 Klarna AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File containing the Capture class.
 */

namespace Klarna\Rest\Settlements;

use GuzzleHttp\Exception\RequestException;
use Klarna\Rest\Resource;
use Klarna\Rest\Transport\Connector;
use Klarna\Rest\Transport\Exception\ConnectorException;

/**
 * Reports resource.
 *
 */
class Reports extends Resource
{
    /**
     * {@inheritDoc}
     */
    const ID_FIELD = 'payment_reference';

    /**
     * {@inheritDoc}
     */
    public static $path = '/settlements/v1/reports';

    /**
     * Constructs an report instance.
     *
     * @param Connector $connector          HTTP transport connector
     */
    public function __construct(Connector $connector)
    {
        parent::__construct($connector);

        $this->setLocation(self::$path);
    }

    /**
     * Get payout CSV report with transactions
     *
     * @param string    $payment_reference  The reference id of the payout
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function getPayoutWithTransactions($payment_reference)
    {
        $params = http_build_query( array(
            'payment_reference' => $payment_reference
        ));
        $this->setLocation(self::$path."/payout-with-transactions?{$params}");

        $data['csv'] = $this->get($this->getLocation())
            ->status('200')
            ->contentType('text/csv')
            ->getResponse()->getBody()->getContents();

        $this->exchangeArray($data);

        return $this;
    }

    /**
     * Get payouts summary CSV report with transactions
     *
     * @param string    $start_date     ISO-8601/DateTime::ATOM formatted date with optional time string  DateTime::ATOM
     * @param string    $end_date       ISO-8601/DateTime::ATOM formatted date with optional time string
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function getPayoutsSummaryWithTransactions($start_date, $end_date)
    {
        $params = http_build_query( array(
            'start_date' => $start_date,
            'end_date' => $end_date
        ));

        $this->setLocation(self::$path."/payouts-summary-with-transactions?{$params}" );
        $data['csv'] = $this->get($this->getLocation())
            ->status('200')
            ->contentType('text/csv')
            ->getResponse()->getBody()->getContents();

        $this->exchangeArray($data);

        return $this;
    }

}
