<?php
/**
 * Copyright 2014 Klarna AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * File containing the Capture class.
 */

namespace Klarna\Rest\Settlements;

use GuzzleHttp\Exception\RequestException;
use Klarna\Rest\Resource;
use Klarna\Rest\Transport\Connector;
use Klarna\Rest\Transport\Exception\ConnectorException;

/**
 * Transactions resource.
 *
 */
class Transactions extends Resource
{
    /**
     * {@inheritDoc}
     */
    const ID_FIELD = 'payment_reference';

    /**
     * {@inheritDoc}
     */
    public static $path = '/settlements/v1/transactions';

    /**
     * Constructs an transaction instance.
     *
     * @param Connector $connector          HTTP transport connector
     */
    public function __construct(Connector $connector)
    {
        parent::__construct($connector);

        $this->setLocation(self::$path);
    }

    /**
     * Fetches the transactions
     *
     * @param string    $payment_reference  The reference id of the payout
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function getTransactions($payment_reference)
    {
        $params = http_build_query( array(
            'payment_reference' => $payment_reference
        ));
        $this->setLocation(self::$path."?{$params}");

        parent::fetch();

        return $this;
    }

    /**
     * Fetches a page of transactions.
     *
     * @param int   $offset page offset, default 0
     * @param int   $size   page size, default 20
     *
     * @throws ConnectorException        When the API replies with an error response
     * @throws RequestException          When an error is encountered
     * @throws \RuntimeException         On an unexpected API response
     * @throws \RuntimeException         If the response content type is not JSON
     * @throws \InvalidArgumentException If the JSON cannot be parsed
     * @throws \LogicException           When Guzzle cannot populate the response
     *
     * @return self
     */
    public function page($offset = 0, $size = 20)
    {
        $params = http_build_query( array(
            'offset' => $offset,
            'size' => $size
        ));
        $this->setLocation(self::$path."?{$params}" );
        parent::fetch();

        return $this;
    }

}
